onChanged property
Notified with the full row set whenever the data changes.
Implementation
final ValueChanged<List<EditableRow>>? onChanged;
Notified with the full row set whenever the data changes.
final ValueChanged<List<EditableRow>>? onChanged;