displayValue method
The string this column shows for row. Stored value for most kinds;
ComputedColumn overrides this to derive it from the whole row.
Implementation
@override
String displayValue(EditableRow row) => compute(row);
The string this column shows for row. Stored value for most kinds;
ComputedColumn overrides this to derive it from the whole row.
@override
String displayValue(EditableRow row) => compute(row);