resetColumnWidth method
Drop the resize override for the column at visual (double-tap the handle).
Implementation
void resetColumnWidth(int visual) {
if (_widthOverride.remove(logicalColumnAt(visual)) != null) notifyListeners();
}
Drop the resize override for the column at visual (double-tap the handle).
void resetColumnWidth(int visual) {
if (_widthOverride.remove(logicalColumnAt(visual)) != null) notifyListeners();
}