ComputedColumn<T> class
Read-only column derived from the whole row (no setValue).
- Inheritance
-
- Object
- EditableColumn<
T> - ComputedColumn
Constructors
-
ComputedColumn({required String label, required String compute(T row), double width = 130, bool includeInTotal = false, EditableCellBuilder<
T> ? cellBuilder, Comparable sortKey(T row)?})
Properties
- align → CellAlign
-
finalinherited
-
cellBuilder
→ EditableCellBuilder<
T> ? -
finalinherited
-
cellValidator
→ EditableCellValidator<
T> ? -
finalinherited
- editableInline → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeInTotal → bool
-
finalinherited
- isReadOnly → bool
-
no setterinherited
- label → String
-
finalinherited
- mono → bool
-
finalinherited
- normalize → String Function(String raw)?
-
Normalise a freshly-typed value on commit (group numbers, reformat dates…).
finalinherited
-
options
→ List<
String> -
finalinherited
- required → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setValue → T Function(T row, String raw)?
-
Apply
rawtorow, returning a NEW row. Null ⇒ read-only.finalinherited - sortKey → Comparable Function(T row)?
-
Typed sort key. Defaults to the display string.
finalinherited
- type → EditableColumnType
-
finalinherited
- validate → String? Function(String value)?
-
finalinherited
- value → String Function(T row)
-
Read the cell's display string for
row.finalinherited - width → double
-
finalinherited
Methods
-
displayValue(
T row) → String -
inherited
-
errorFor(
String v, [T? row]) → String? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortValue(
T row) → Comparable -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited