CellRef class

An immutable cell address (row + column index) — the controller's cursor.

Annotations

Constructors

CellRef(int row, int col)
const

Properties

col int
final
hashCode int
The hash code for this object.
no setteroverride
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? row, int? col}) CellRef
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override