displayValue method
The string this column shows for row. Stored value for most kinds;
ComputedColumn overrides this to derive it from the whole row.
Implementation
String displayValue(EditableRow row) => row[key] ?? '';
The string this column shows for row. Stored value for most kinds;
ComputedColumn overrides this to derive it from the whole row.
String displayValue(EditableRow row) => row[key] ?? '';