EditableTableThemeData class
- Inheritance
-
- Object
- ThemeExtension<
EditableTableThemeData> - EditableTableThemeData
- Annotations
Constructors
Properties
- bg → Color
-
final
- border → Color
-
final
- borderStrong → Color
-
final
- fg1 → Color
-
final
- fg2 → Color
-
final
- fg3 → Color
-
final
- fg4 → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hover → Color
-
final
- inputBg → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → Color
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? bg, Color? surface, Color? inputBg, Color? hover, Color? border, Color? borderStrong, Color? fg1, Color? fg2, Color? fg3, Color? fg4}) → EditableTableThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< EditableTableThemeData> ? other, double t) → EditableTableThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectionFill(
[double pct = 0.10]) → Color -
A selection tint at
pctopacity over surface (mirrors the webcolor-mix(... accent N%, surface)cell highlight). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → EditableTableThemeData - Reads the registered extension, or falls back to dark.
Constants
- accent → const Color
- actionsWidth → const double
- bodyFont → const String
- curveStandard → const Curve
- danger → const Color
- dark → const EditableTableThemeData
- displayFont → const String
- durBase → const Duration
- durFast → const Duration
- gutterWidth → const double
- headerHeight → const double
- light → const EditableTableThemeData
- monoFont → const String
-
popShadow
→ const List<
BoxShadow> - radiusLg → const double
- radiusMd → const double
- radiusSm → const double
- rowHeight → const double
- success → const Color
- warning → const Color