onCellSelectionChanged property
Fires with the set of selected cells whenever it changes.
Implementation
final ValueChanged<Set<ReadableCell>>? onCellSelectionChanged;
Fires with the set of selected cells whenever it changes.
final ValueChanged<Set<ReadableCell>>? onCellSelectionChanged;