selectionMode property
What the user can select. Mutable so the view's selectionMode: can
drive it; clears the selection when the kind of selection changes.
Implementation
ReadableSelectionMode selectionMode;
What the user can select. Mutable so the view's selectionMode: can
drive it; clears the selection when the kind of selection changes.
ReadableSelectionMode selectionMode;