ReadableSelectionMode enum

What a ReadableTable / its controller lets the user select.

Inheritance
Available extensions

Values

none → const ReadableSelectionMode

No selection layer (display only). Default — fully backward-compatible.

singleRow → const ReadableSelectionMode

Exactly one row at a time.

multiRow → const ReadableSelectionMode

Any number of rows (Ctrl/⌘-click toggles, Shift extends a range, ⌘/Ctrl+A selects all).

singleCell → const ReadableSelectionMode

Exactly one cell at a time.

multiCell → const ReadableSelectionMode

Any number of cells (Ctrl/⌘-click toggles, Shift extends a rectangle).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReadableSelectionMode>
A constant List of the values in this enum, in order of their declaration.