folder property

bool? folder
final

Whether this node can hold children — i.e. renders a disclosure twisty and accepts "add child". When null it's inferred: a node is a folder iff it currently has children. Set true for an empty folder, false to force a leaf even though children were supplied.

Implementation

final bool? folder;