TreeNodeId typedef
TreeNodeId = String
Stable identity of a node. Kept as a String so hosts can use their own keys (paths, uuids, db ids) without adapting.
Implementation
typedef TreeNodeId = String;
Stable identity of a node. Kept as a String so hosts can use their own keys (paths, uuids, db ids) without adapting.
typedef TreeNodeId = String;