ancestorHasNext property

List<bool> ancestorHasNext
final

For each ancestor depth, whether that ancestor has a following sibling — i.e. whether to draw a continuing vertical guide at that column.

Implementation

final List<bool> ancestorHasNext;