TreeSelectionMode enum

What a Tree lets the user select via clicks / keyboard (independent of the checkbox layer, which is always available when showCheckboxes is on).

Inheritance
Available extensions

Values

none → const TreeSelectionMode

No click-selection layer (display / navigation only).

single → const TreeSelectionMode

Exactly one node at a time (the classic behaviour).

multi → const TreeSelectionMode

Any number of nodes — Ctrl/⌘-click toggles one, Shift-click selects the contiguous visible range from the anchor, plain click resets to one.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() TreeNodeId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TreeSelectionMode>
A constant List of the values in this enum, in order of their declaration.