TreeThemeData class

Inheritance
Annotations

Constructors

TreeThemeData({required Color bg, required Color surface, required Color inputBg, required Color hover, required Color border, required Color borderStrong, required Color guide, required Color fg1, required Color fg2, required Color fg3, required Color fg4})
const

Properties

bg Color
final
border Color
final
borderStrong Color
final
fg1 Color
final
fg2 Color
final
fg3 Color
final
fg4 Color
final
guide Color
final
hashCode int
The hash code for this object.
no setterinherited
hover Color
final
inputBg Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surface Color
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? bg, Color? surface, Color? inputBg, Color? hover, Color? border, Color? borderStrong, Color? guide, Color? fg1, Color? fg2, Color? fg3, Color? fg4}) TreeThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<TreeThemeData>? other, double t) TreeThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectionFill([double pct = 0.14]) Color
Selection-row tint at pct opacity over surface (mirrors the web color-mix(... accent N%, surface) highlight).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) TreeThemeData
Reads the registered extension, or falls back to dark.

Constants

accent → const Color
bodyFont → const String
curveStandard → const Curve
danger → const Color
dark → const TreeThemeData
displayFont → const String
durBase → const Duration
durFast → const Duration
footerHeight → const double
iconSize → const double
indentStep → const double
light → const TreeThemeData
monoFont → const String
popShadow → const List<BoxShadow>
radiusLg → const double
radiusMd → const double
radiusSm → const double
rowHeight → const double
success → const Color
toolbarHeight → const double
twistySize → const double
warning → const Color