mode property
How the sidebar is presented. Hosts typically derive this from the available width with NavSidebarBreakpoints.
Implementation
final NavSidebarMode mode;
How the sidebar is presented. Hosts typically derive this from the available width with NavSidebarBreakpoints.
final NavSidebarMode mode;