ownsActive method

bool ownsActive(
  1. NavNodeId id
)

Whether id is on the path to the active node (used to accent-tint an ancestor module/group even while the leaf itself is the active row).

Implementation

bool ownsActive(NavNodeId id) =>
    _active != null && NavOps.ancestorsOf<T>(_sections, _active!).contains(id);