NavSection<T> class

A titled band of the sidebar (e.g. Overview, Finance). The title is the small uppercase eyebrow above the band; items are its top-level nodes.

Annotations

Constructors

const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<NavNode<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited