BrowserTab class

A single workspace tab. Generic / no business-model coupling.

Constructors

BrowserTab({required int id, required String title, required GLTabKind kind, bool dirty = false, bool pinned = false})

Properties

dirty bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
final
kind GLTabKind
final
pinned bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

copyWith({int? id, String? title, GLTabKind? kind, bool? dirty, bool? pinned}) BrowserTab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited