EditableCellData<T> class
Everything a custom cell renderer needs — generic over the row value.
- Annotations
Constructors
-
EditableCellData({required int row, required int col, required String value, required T rowData, required EditableColumn<
T> column, required bool selected, required bool invalid, required VoidCallback requestEdit}) -
const
Properties
- col → int
-
final
-
column
→ EditableColumn<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalid → bool
-
final
- requestEdit → VoidCallback
-
final
- row → int
-
final
- rowData → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited