EditableColumn<T> class
The schema for one column, generic over the row value T.
- Implementers
- Annotations
Constructors
-
EditableColumn({required String label, required String value(T row), T setValue(T row, String raw)?, double width = 160, CellAlign? align, bool mono = false, bool required = false, EditableColumnType type = EditableColumnType.text, List<
String> options = const [], bool includeInTotal = false, String normalize(String raw)?, Comparable sortKey(T row)?, String? validate(String value)?, EditableCellValidator<T> ? cellValidator, EditableCellBuilder<T> ? cellBuilder}) -
const
Properties
- align → CellAlign
-
final
-
cellBuilder
→ EditableCellBuilder<
T> ? -
final
-
cellValidator
→ EditableCellValidator<
T> ? -
final
- editableInline → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeInTotal → bool
-
final
- isReadOnly → bool
-
no setter
- label → String
-
final
- mono → bool
-
final
- normalize → String Function(String raw)?
-
Normalise a freshly-typed value on commit (group numbers, reformat dates…).
final
-
options
→ List<
String> -
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setValue → T Function(T row, String raw)?
-
Apply
rawtorow, returning a NEW row. Null ⇒ read-only.final - sortKey → Comparable Function(T row)?
-
Typed sort key. Defaults to the display string.
final
- type → EditableColumnType
-
final
- validate → String? Function(String value)?
-
final
- value → String Function(T row)
-
Read the cell's display string for
row.final - width → double
-
final
Methods
-
displayValue(
T row) → String -
errorFor(
String v, [T? row]) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortValue(
T row) → Comparable -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited