ReadableCells class
Static builders, one per ReadableColumnType. Held in a class purely as a
namespace so the model can reference ReadableCells.number(...) etc.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
badge(
String tag, {Color color(String)?}) → Widget -
color(
String hex) → Widget -
date(
DateTime value, {String format(DateTime)?}) → Widget -
link(
String text, {VoidCallback? onTap}) → Widget -
number(
num value, {int decimals = 2, String? suffix, bool colorSign = false}) → Widget -
progress(
double ratio) → Widget -
text(
String value, {String? secondary}) → Widget -
time(
String hhmm) → Widget