TreeAction<T> class
One entry in a node's context menu (right-click or the ⋯ affordance).
Constructors
-
TreeAction({required String label, IconData? icon, bool danger = false, required void onSelected(TreeController<
T> c, TreeNode<T> node)}) -
const
Properties
- danger → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- label → String
-
final
-
onSelected
→ void Function(TreeController<
T> c, TreeNode<T> node) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited