NavSection<T> class
A titled band of the sidebar (e.g. Overview, Finance). The title is the small uppercase eyebrow above the band; items are its top-level nodes.
- Annotations
Constructors
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited