NavSidebarBreakpoints class
Width thresholds that map an available width to a NavSidebarMode — the
Flutter analogue of the web getNavMode(w). Tune per app.
- Annotations
Constructors
-
const
Properties
- expanded → double
-
At/above this the sidebar is NavSidebarMode.expanded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rail → double
-
At/above this (but below expanded) it's a NavSidebarMode.rail;
below it the sidebar becomes a NavSidebarMode.drawer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
modeFor(
double width) → NavSidebarMode -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited