TabMenuItem class
Constructors
- TabMenuItem({IconData? icon, String? label, String? hint, bool danger = false, bool disabled = false, VoidCallback? run})
-
const
- TabMenuItem.divider()
-
const
Properties
- danger → bool
-
final
- disabled → bool
-
final
- divider → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- icon → IconData?
-
final
- label → String?
-
final
- run → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited